#!/usr/bin/python
import string, sys, operator, getopt

rev = "0.0.5"

# smgcfg.py - converts a .csv file containing SMG configuration information 
#             into the .conf files required by the SMG system
#
# rev history
# -------------------------------------------------------------------------------
# 0.0.1 - initial release
# 0.0.2 - 2008-12-11 Th; implement requirement that first SMG interface 
#          activated is a TDM_VOICE_API;
#          this means that if ss7boxd is running then the first wanpipe started by
#          ss7boxd must first activate a TDM_VOICE_API interface; this interface must
#          be either real or an unused dummy; if ss7boxd is not running then the first
#          SMG wanpipe will activate a TDM_VOICE_API interface by default so nothing
#          is needed in this program in this case; implementing this requirement means
#          that ss7box config information is needed before making the wanpipe conf files,
#          there will be a change in the order of tasks in this program: first collect
#          info then build conf files
# 0.0.3 - 2009-01-21; changed ss7boost.conf default hearbeat rate to 5.00 sec;
#          wXgY interface names for xmtp2 links must have Y==active channel; this means 
#          the voice wXgY name will have a Y value that is not an SS7 link channel
# 0.0.4 - 2009-01-21; extended wXgY concept to ss7boost.conf TRUNK section
# 0.0.5 - 2009-02-27 Fr; path_entry had no index 3 if no B linkset defined; checked len 
#          before using index 3

# TODO list
# 1. create wanrouter.rc
# 3. create the tgX_.... timer conf files
# 4. ss7box.conf, SS7BOOST_RTE, each rte entry must have port = 50220 + (2*index); this port must be 
#    used in the cluster nodes ss7boost.conf SS7BOX section.
# 5. HW echo control option
# 6. allow for more than 1 ss7 link per span
# 7. accomodate upcoming individual span/chan assignment of CIC and t-g

def sp_voice_if_name (wp_num, voicechans):
	voicechanseg= voicechans.split('.')
	voicechanrange = voicechanseg[0].split('-')
	wXgY_voice = "w" + wp_num + "g" + voicechanrange[0]
	return wXgY_voice

def make_wanpipe_conf_file (wanpipe_activates_first_ss7_link, vl):
	if wanpipe_activates_first_ss7_link:
		print "tdm voice api interface goes first"
	else:
		print "tdm voice api oder as read"
	wp = "wanpipe" + vl[1]
	wX = "w" + vl[1]
	gY_ss7link = "g" + vl[10]
	wXgY_ss7link = wX + gY_ss7link
	wXgY_voice = sp_voice_if_name (vl[1], vl[12])
	fn = wp + ".conf"
	#print fn
	#print vl
	print "creating %s.conf" % wp
	fout = open (fn, 'w')
	fout.write ("# Created by smgcfg.py, Revision %s\n\n" % rev)
	fout.write ("[devices]\n")
	fout.write ("%s  = WAN_AFT_TE1, Comment\n" % wp)
	fout.write ("\n[interfaces]\n")
	print wp
	# put TDM_VOICE_API interfaces first 
	if vl[14] != "":
		print "\tVOICE:\tYES"
		fout.write ("%s      = %s, , TDM_VOICE_API, Comment\n" % (wXgY_voice, wp))
	else:
		print "\tVOICE:\tNO"
		if wanpipe_activates_first_ss7_link:
			fout.write ("%s      = %s, , TDM_VOICE_API, Comment\n" % (wXgY_voice, wp))
	if vl[10] != "":
		print "\tSS7:\tYES"
		fout.write ("%s      = %s, , XMTP2_API, Comment\n" % (wXgY_ss7link, wp))
	else:
		print "\tSS7:\tNO"
	fout.write ("\n[%s]\n" % wp)
	fout.write ("CARD_TYPE        = AFT\n")
	fout.write ("S514CPU          = A\n")
	fout.write ("CommPort         = PRI\n")
	fout.write ("AUTO_PCISLOT     = NO\n")
	fout.write ("PCISLOT          = %s\n" % vl[2])
	fout.write ("PCIBUS           = %s\n" % vl[3])
	fout.write ("FE_MEDIA         = %s\n" % vl[15])
	fout.write ("FE_LCODE         = %s\n" % vl[16])
	fout.write ("FE_FRAME         = %s\n" % vl[17])
	fout.write ("FE_LINE          = %s\n" % vl[4])
	fout.write ("TE_CLOCK         = %s\n" % vl[18].rstrip())
	fout.write ("TE_REF_CLOCK     = 0\n")
	fout.write ("TE_HIGHIMPEDANCE = NO\n")
	if vl[15] == "T1":
		fout.write ("LBO              = 0DB\n")
	else:
		fout.write ("LBO              = 120OH\n")
	fout.write ("FE_TXTRISTATE    = NO\n")
	fout.write ("MTU              = 1500\n")
	fout.write ("UDPPORT          = 9000\n")
	fout.write ("TTL              = 255\n")
	fout.write ("IGNORE_FRONT_END = NO\n")
	if vl[14] != "":
		fout.write ("TDMV_SPAN        = %s\n" % vl[5])
	elif wanpipe_activates_first_ss7_link:
		fout.write ("TDMV_SPAN        = 100\n")
	#fout.write ("TDMV_DCHAN       = 0\n")
	if vl[14] != "":
		fout.write ("\n[%s]\n" % wXgY_voice)
		fout.write ("ACTIVE_CH        = %s\n" % vl[12])
		fout.write ("TDMV_ECHO_OFF    = NO\n")
		fout.write ("TDMV_HWEC        = NO\n")
		fout.write ("MTU              = 80\n")
	# this is the ss7 link stanza - only one ss7 link supported
	if vl[10] != "":
		fout.write ("\n[%s]\n" % wXgY_ss7link)
		fout.write ("ACTIVE_CH        = %s\n" % vl[10])
		fout.write ("MTU              = 80\n")
		fout.write ("MRU              = 80\n")
		fout.write ("TDMV_ECHO_OFF    = NO\n")
		fout.write ("TDMV_HWEC        = NO\n")
		fout.write ("\n[%sxmtp2]\n" % wXgY_ss7link)
		fout.write ("\n[%s.xmtp2]\n" % wXgY_ss7link)
	#fout.write ("\n")
	#fout.write ("%s\n" % vl[])
	#fout.write ("Protocol:           %s\n" % (entry[1]))
	fout.close ()
	#print
	return

def write_ss7box_conf (port, protocol, spc, ac, lslink, ls, path, rte, isup_rte):
	
	ss7_fac = []
	
	print "\twrite ss7box.conf: spc %s ac %s" % (spc, ac)

	fout = open ("ss7box.conf", 'w')
	fout.write ("# ss7box.conf\n")
	fout.write ("# Created by smgcfg.py, Revision %s\n\n" % rev)
	fout.write ("[GLOBAL]\n")
	fout.write ("# SS7 Prot./Self Point/Code Serial No./Authorization Code/Verbose Group\n")
	fout.write (" %s  %s  %s  %s  %s\n" % (protocol, spc, "abcdefg", ac, "1"))
	fout.write ("\n[CLI]\n")
	fout.write ("# local address/port\n")
	fout.write (" 127.0.0.104  55063\n" % ())
	fout.write ("# remote address/port\n")
	fout.write (" 127.0.0.105  55063\n")
	fout.write ("\n[CROSSLINK]\n")
	fout.write ("# mode/local-address/local-port/remote-address/remote-port\n")
	fout.write (" SIMPLEX na na na na\n")
	fout.write ("\n[FACILITIES]\n")
	fout.write ("# index/wanpipeX/frames-per-packet/clear-channel\n")
	# search port list for entries with a sig chan field; make a list with these port entries;
	# write the facility entries
	fac_index = 0
	for port_entry in port:
		if port_entry[10] != "":
			print "\t\twanpipe %s has an ss7 link" % port_entry[1]
			port_entry = port_entry + [str(fac_index)]
			ss7_fac.append(port_entry)
			fout.write (" %s  %s  80  %s\n" % (port_entry[19], port_entry[1], port_entry[11]))
			fac_index = fac_index + 1
	fout.write ("end\n")
	#print ss7_wanpipe
	link_index = 0
	fout.write ("\n[MTP2LINKS]\n")
	fout.write ("# index/fac-index/slot/lset/link/T1/T2/T3/T4e/T4n/T5/T6/T7\n")
	for lslink_entry in lslink:
		# find facility index for this link
		for ss7_fac_entry in ss7_fac:
			if ss7_fac_entry[1] == lslink_entry[4]:
				fout.write (
					" %s  %s  %s  %s  %s  13.00  11.50  11.50  0.60  2.30  0.12  3.00  1.00\n" % 
					( 	lslink_entry[1], 
						ss7_fac_entry[19], 
						lslink_entry[5], 
						lslink_entry[2], 
						lslink_entry[3]))

	fout.write ("end\n")
	fout.write ("\n[MTP3TIMERS]\n")
	fout.write ("# timer-id/value\n")
	fout.write (" 1\t0.80\n")
	fout.write (" 2\t1.40\n")
	fout.write (" 3\t0.80\n")
	fout.write (" 4\t0.80\n")
	fout.write (" 5\t0.80\n")
	fout.write (" 6\t0.80\n")
	fout.write (" 7\t1.50\n")
	fout.write (" 8\t1.20\n")
	fout.write (" 9\t0.00\n")
	fout.write (" 10\t30.00\n")
	fout.write (" 11\t30.00\n")
	fout.write (" 12\t1.50\n")
	fout.write (" 13\t1.50\n")
	fout.write (" 14\t3.00\n")
	fout.write (" 15\t3.00\n")
	fout.write (" 16\t2.00\n")
	fout.write (" 17\t1.50\n")
	fout.write (" 18\t20.00\n")
	fout.write (" 19\t600.00\n")
	fout.write (" 20\t120.00\n")
	fout.write (" 21\t120.00\n")
	fout.write (" 22\t15.00\n")
	fout.write (" 23\t15.00\n")
	fout.write (" 24\t15.00\n")
	fout.write (" 25\t35.00\n")
	fout.write (" 26\t15.00\n")
	fout.write (" 27\t5.00\n")
	fout.write (" 28\t35.00\n")
	fout.write (" 29\t65.00\n")
	fout.write (" 30\t35.00\n")
	fout.write (" 31\t120.00\n")
	fout.write (" 32\t120.00\n")
	fout.write (" 33\t600.00\n")
	fout.write (" 34\t120.00\n")
	fout.write ("# Periodic Facility Check Timer\n")
	fout.write (" 35\t20.00\n")
	fout.write ("# Periodic Signaling Link Test Message Timer\n")
	fout.write (" 36\t20.00\n")
	fout.write ("# Crosslink Test Acknowledge Timer (must be less the timer 35 Periodic Facility Check Timer\n")
	fout.write ("# that controls the Crosslink Test Message)\n")
	fout.write (" 37\t5.00\n")

	fout.write ("\n[MTP3LINKSETS]\n")
	if protocol == "ANSI": 
		fout.write ("# ls-id/APC-net/APC-clu/APC-mem/slt/prio/ni/SLC-link-index-list\n")
	else:
		fout.write ("# ls-id/APC/slt/prio/ni/SLC-link-index-list\n")
	for ls_entry in ls:
		fout.write (
			"   %s %s %s %s %s" % (
				ls_entry[1], ls_entry[2], ls_entry[3], ls_entry[4], ls_entry[5].strip()))
		slc_list = ['na', 'na', 'na', 'na', 'na', 'na', 'na', 'na', 'na', 'na', 'na', 'na', 'na', 'na', 'na', 'na']
		for lslink_entry in lslink:
			if lslink_entry[2] == ls_entry[1]:
				slc_list[int(lslink_entry[3])] = lslink_entry[1]
		for slc in slc_list:
			fout.write (" %s" % slc)
		fout.write ("\n")
	fout.write ("end\n")
		
	fout.write ("\n[PATHS]\n")
	fout.write ("# Index/Linkset-A/Linkset-B (optional)\n")
	for path_entry in path:
		print "path_entry"
		print path_entry
		if len(path_entry) == 3:
			path_entry.append ("na")
		fout.write (
			"   %s %s %s\n" % (path_entry[1], path_entry[2], path_entry[3]))
	fout.write ("end\n")

	fout.write ("\n[ROUTES]\n")
	fout.write ("# Index/DPC/Protocol/P-Path/A-Path/Crosslink\n")
	for rte_entry in rte:
		if rte_entry[4] == "":
			rte_entry[4] = "na"
		fout.write (
			"   %s %s MTP3 %s %s %s\n" % (rte_entry[1], rte_entry[2], rte_entry[3], rte_entry[4], rte_entry[5]))
	fout.write ("end\n")

	fout.write ("\n[SS7BOOST_ISUP]\n")
	fout.write ("# Index/DPC/OPC/CIC-start/CIC-end/lcl-addr/lcl-port/rmt-addr/rmt-port\n")
	for irte_entry in isup_rte:
		fout.write (
			"   %s   %s   \t%s\t%s %s\t%s %s %s %s\n" % 
			(
				irte_entry[1], 
				irte_entry[2], 
				irte_entry[3], 
				irte_entry[4], 
				irte_entry[5], 
				irte_entry[6], 
				irte_entry[7], 
				irte_entry[8], 
				irte_entry[9]
			))
	fout.write ("end\n")

	fout.close ()
	return

def write_ss7boost_conf (protocol, spc, sysid, ss7box_ap, port, trunk_group):

	trunk = []

	print "\twrite ss7boost.conf"
			
	fout = open ("ss7boost.conf", 'w')
	fout.write ("# ss7boost.conf\n")
	fout.write ("# Created by smgcfg.py, Revision %s\n\n" % rev)

	fout.write ("\n[SS7BOOST]\n")
	if protocol == "ANSI":
		fout.write ("# SS7-Protocol/SPC-net/SPC-clu/SPC-mem/System-Id/Verbose-Grp-ID\n")
	else:
		fout.write ("# SS7-Protocol/SPC/System-Id/Verbose-Grp-ID\n")
	fout.write ("   %s %s %s 1\n" % (protocol, spc, sysid))
	
	fout.write ("\n[SS7BOX]\n")
	fout.write ("# lcl-addr/lcl-port\n")
	fout.write ("  %s  %s\n" % (ss7box_ap[2], ss7box_ap[3]))
	fout.write ("# rmt-addr/rmt-port\n")
	fout.write ("  %s  %s\n" % (ss7box_ap[4], ss7box_ap[5]))
	
	fout.write ("\n[SANGOMA_MGD]\n")
	fout.write ("# lcl-addr/lcl-port\n")
	fout.write ("  127.0.0.66  53000\n")
	fout.write ("# rmt-addr/rmt-port\n")
	fout.write ("  127.0.0.65  53000\n")
	
	fout.write ("\n[CLI]\n")
	fout.write ("# lcl-addr/lcl-port\n")
	fout.write ("  127.0.0.92  55000\n")
	fout.write ("# rmt-addr/rmt-port\n")
	fout.write ("  127.0.0.93  55000\n")
	
	fout.write ("\n[CDR]\n")
	fout.write ("# Automatic CDR Logging at Startup\n")
        fout.write ("   n\n")
	fout.write ("# lcl-addr/lcl-port\n")
	fout.write ("  127.0.0.92  55001\n")
	fout.write ("# rmt-addr/rmt-port\n")
	fout.write ("  127.0.0.93  55001\n")

	fout.write ("\n[CALL_ENGINE_API]\n")
	fout.write ("# lcl-addr/lcl-port\n")
	fout.write ("  127.0.0.92  55002\n")
	fout.write ("# rmt-addr/rmt-port\n")
	fout.write ("  127.0.0.93  55002\n")
	
	fout.write ("\n[SYSTEM_TIMERS]\n")
	fout.write ("# index/timer\n")
	fout.write ("  0       0.00 	# base, unused\n")
	fout.write ("  1       5.00	# heartbeat rate\n")
	fout.write ("  2      45.00	# call stop\n")
	fout.write ("  3       1.00	# circuit maintenance gap timer\n")
	fout.write ("  4      20.00	# automatic call gap timer\n")
	fout.write ("  5      60.00	# circuit quarantine timer; timer 2 + n\n")
	fout.write ("  6       0.00	# last, unused\n")

	fout.write ("\n[TRUNK]\n")
	fout.write ("# index/voice-trk-grp/facility-type/cic-base/non-voice-channels\n")
	# the voice trunk list is a subset of the port list, and is sorted on the 
	# ss7boost trunk ID number
	for port_entry in port:
		if port_entry[6] != "":
			trunk.append (port_entry)
	trunk.sort(lambda x, y:cmp(int(x[6]), int(y[6])))
	#print "voice trunk list:"
	for trunk_entry in trunk:
		#print trunk_entry
		wXgY_voice = sp_voice_if_name (trunk_entry[1], trunk_entry[12])
		fout.write ("   %s %s %s %s" % (
			trunk_entry[6], 
			wXgY_voice, 
			trunk_entry[15],
			trunk_entry[13]
			))
		# make list of voice and non-voice channels
		channel_map = [
			"nv", "nv", "nv", "nv", "nv", "nv", "nv", "nv", "nv", "nv", 
			"nv", "nv", "nv", "nv", "nv", "nv", "nv", "nv", "nv", "nv", 
			"nv", "nv", "nv", "nv", "nv", "nv", "nv", "nv", "nv", "nv", 
			"nv"
			]
		if trunk_entry[15] == "T1":
			num_chans = 24
		else:
			num_chans = 31
		vc_seg = trunk_entry[12].split(".")
		print "voice channel segements"
		for vc_seg_entry in vc_seg:
			#print vc_entry
			vc_range = vc_seg_entry.split("-")
			range_begin = int(vc_range[0])
			if len(vc_range) == 2:
				range_end = int(vc_range[1])
			else:
				range_end = int(vc_range[0])
			#print "range begin: %d end: %d" % (range_begin, range_end)
			i = range_begin - 1 # decrease because ss7boost range is 0..n
			while i < range_end:
				channel_map[i] = "v"
				i = i + 1
		#print channel_map
		i = 0
		while i < num_chans:
			if channel_map[i] == "nv":
				fout.write (" %s" % str(i))
			i = i + 1
		fout.write (" end\n")
	fout.write (" end\n")
	
	fout.write ("\n[TRUNK_GROUP]\n")
	if protocol == "ANSI":
		fout.write ("# A/B-net/B-clu/B-mem/C/D/E/F/G/H/I/J/K/L/Z\n")
	else:
		fout.write ("# A/B/C/D/E/F/G/H/I/J/K/L/Z\n")
	for tg_entry in trunk_group:
		#print tg_entry
		if tg_entry[5] == "up":
			tg_entry[5] = "n"
		else:
			tg_entry[5] = "y"
		fout.write (
			"   %s %s %s %s %s %s %s %s %s %s %s %s begin" % (
				tg_entry[1],
				tg_entry[2],
				tg_entry[3],
				tg_entry[4],
				tg_entry[5],
				tg_entry[6],
				tg_entry[7],
				tg_entry[8],
				tg_entry[9],
				tg_entry[10],
				tg_entry[11],
				tg_entry[12]
				))
		i = 13
		while tg_entry[i].strip() != "end":
			fout.write (" %s" % tg_entry[i])
			i = i + 1
			if i == 13 + 64:
				print "FATAL: too many trunks in trunk group"
				sys.exit(3)
		fout.write (" end\n")
	fout.write (" end\n")

	if protocol == "ANSI":
		fout.write ("\n[GTT_TYPE]\n")
		fout.write ("# GTT-Type/SSN/Function-ID\n")
		fout.write ("   11           210       5 # CNAM\n")
		fout.write ("   20           106       6 # LNP\n")
		fout.write ("   30           107       7 # TFS\n")
		fout.write ("   40           108       8 # LIDB\n")
		fout.write ("   50           109       9 # MAP\n")
		fout.write ("   60           110      10 # HLR\n")
		fout.write ("   70           111      11 # VLR\n")
		fout.write ("end\n")

		fout.write ("\n[CAPABILITY_CODES]\n")
		fout.write ("#  Index/Cap-PC-net/Cap-PC-clu/Cap-PC-mem/Message-Priority/Network-Indicator\n")
		fout.write ("   0  5 128 5  0  2  # CNAM\n")
		fout.write ("   1  5 128 6  0  2  # LIDB\n")
		fout.write ("   2  5 128 7  0  2  # LNP\n")
		fout.write ("   3  5 128 8  0  2  # Free Call\n")
		fout.write ("end\n")

	return

def usage():
	print
	sys.stderr.write('Usage:\n')
	sys.stderr.write('     smgcfg.py -h       // help\n');
	sys.stderr.write('     smgcfg.py -f <path/filename of CSV input file>\n')
	sys.stderr.write('\n')
	sys.exit(2)
	return

#----main----

try:
	optList, args = getopt.getopt(sys.argv[1:], 'f:h', ['help'])
except getopt.GetoptError:
	usage()

fn = ""

for o, a in optList:
	if o in ("-h", "--help"):
		usage()
	elif o == "-f":
		fn = a
	else:
		usage()

if fn == "":
	usage()

found_ports_section = 0
found_ss7box_section = 0
found_ss7boost_section = 0
collect_ss7box_data = 0
collect_ss7boost_data = 0
port = []
protocol = ""
ss7box_spc = ""
ac = ""
lslink = []
lslink_cnt = 0
ls = []
ls_cnt = 0
path = []
path_cnt = 0
rte = []
rte_cnt = 0
isup_rte = []
isup_rte_cnt = 0
ss7boost_spc = ""
ss7boost_sysid = ""
ss7boost_ss7box_ap = []
tg_cnt = 0
trunk_group = []
first_wanpipe_with_ss7_link_found = 0

print
print "The contents of %s follows:" % fn
print

try:
	fin = open (fn)
except IOError:
	print "Could not open file: %s" % fn
	print
	sys.exit(1)

L = fin.readline ()
while len(L) != 0:
	var_list = L.split (",")
	#var_list_len = len(var_list)
	#print var_list_len
	#print var_list
	#print "-%s-" % var_list[0]
	if var_list[0].strip() == "end":
		if found_ports_section:
			print "PORTS END"
			print port
			found_ports_section = 0
		if found_ss7box_section:
			found_ss7box_section = 0
			#if collect_ss7box_data:
			#	write_ss7box_conf (port, protocol, ss7box_spc, ac, lslink, ls, path, rte, isup_rte)
			print "SS7BOX END"
		if found_ss7boost_section:
			found_ss7boost_section = 0
			#write_ss7boost_conf (
			#			protocol, 
			#			ss7boost_spc, 
			#			ss7boost_sysid,
			#			ss7boost_ss7box_ap,
			#			port,
			#			trunk_group)
			print "SS7BOOST END"
	if found_ports_section:
		if var_list[9] == "ss7":
			print "wanpipe%s is controlled by SS7" % var_list[1]
			#make_wanpipe_conf_file (var_list)
			port.append(var_list)
	if found_ss7box_section:
		if collect_ss7box_data == 1:
			# ss7box spc
			if var_list[1] == "SPC":
				print "\tget spc"
				ss7box_spc = var_list[2].strip()
				print ss7box_spc
				collect_ss7box_data = collect_ss7box_data + 1
			else:
				print "malformed ss7box SPC section"
				print var_list
				sys.exit(3)
		elif collect_ss7box_data == 2:
			# ss7box authcode
			if (len(var_list) < 3):
				print "authcode missing"
				sys.exit(3)
			if (var_list[2] == ""):
				print "authcode incorrect"
				sys.exit(3)
			print "\tget authcode"
			ac = var_list[2].strip()
			print ac
			collect_ss7box_data = collect_ss7box_data + 1
		elif collect_ss7box_data == 3:
			# ss7box linkset-links
			if len(var_list) < 2:
				print "\t\tempty line before linkset-link section"
			elif var_list[1] == "linkset-links":
				print "\tget linkset link data"
			elif var_list[1].strip() == "end":
				collect_ss7box_data = collect_ss7box_data + 1
				print lslink
			elif var_list[1] == str(lslink_cnt):
				print "\t\tlinkset-link %s" % var_list[1]
				# adjust slot to ss7boost 0..n numbering
				var_list[5] = str(int(var_list[5]) - 1)
				print "\t\tmodified linkset-link entry"
				print var_list
				lslink.append(var_list)
				lslink_cnt = lslink_cnt + 1
			elif var_list[1] == "":
				print "\t\tempty line in linkset-link section"
			else:
				print "\t\tpoorly formed linkset-link section"
				print var_list
		elif collect_ss7box_data == 4:
			# ss7box linksets
			if len(var_list) < 2:
				print "\t\tempty line before linkset section"
			elif var_list[1] == "linkset":
				print "\tget linkset data"
			elif var_list[1].strip() == "end":
				collect_ss7box_data = collect_ss7box_data + 1
			elif var_list[1] == str(ls_cnt):
				print "\t\tlinkset %s" % var_list[1]
				ls.append(var_list)
				#print ls
				ls_cnt = ls_cnt + 1
			elif var_list[1] == "":
				print "\t\tempty line in linkset section"
			else:
				print "\t\tpoorly formed linkset section"
				print var_list
		elif collect_ss7box_data == 5:
			# ss7box paths
			if len(var_list) < 2:
				print "\t\tempty line before path section"
			elif var_list[1] == "path":
				print "\tget path data"
			elif var_list[1].strip() == "end":
				collect_ss7box_data = collect_ss7box_data + 1
			elif var_list[1] == str(path_cnt):
				print "\t\tpath %s" % var_list[1]
				path.append(var_list)
				#print path
				path_cnt = path_cnt + 1
			elif var_list[1] == "":
				print "\t\tempty line in path section"
			else:
				print "\t\tpoorly formed path section"
				print var_list
		elif collect_ss7box_data == 6:
			# ss7box routes
			if len(var_list) < 2:
				print "\t\tempty line before route section"
			elif var_list[1] == "route":
				print "\tget route data"
			elif var_list[1].strip() == "end":
				collect_ss7box_data = collect_ss7box_data + 1
			elif var_list[1] == str(rte_cnt):
				print "\t\troute %s" % var_list[1]
				rte.append(var_list)
				#print rte
				rte_cnt = rte_cnt + 1
			elif var_list[1] == "":
				print "\t\tempty line in route section"
			else:
				print "\t\tpoorly formed rte section"
				print var_list
		elif collect_ss7box_data == 7:
			# ss7box isup routes
			if len(var_list) < 2:
				print "\t\tempty line before inbound isup route section"
			elif var_list[1] == "isup rte":
				print "\tget isup route data"
			elif var_list[1].strip() == "end":
				collect_ss7box_data = collect_ss7box_data + 1
			elif var_list[1] == str(isup_rte_cnt):
				print "\t\tisup route %s" % var_list[1]
				isup_rte.append(var_list)
				#print isup_rte
				isup_rte_cnt = isup_rte_cnt + 1
			elif var_list[1] == "":
				print "\t\tempty line in isup route section"
			else:
				print "FATAL: poorly formed isup route section"
				print var_list
				sys.exit(3)
		else:
			print "extra stuff at the end of the ss7box section"
	if found_ss7boost_section:
		if collect_ss7boost_data == 1:
			if var_list[1] == "sysid":
				print "\tget sysid"
				ss7boost_sysid = var_list[2].strip()
				collect_ss7boost_data = collect_ss7boost_data + 1
			else:
				print "FATAL: poorly formed ss7boost section; missing sysid"
				sys.exit(3)
		elif collect_ss7boost_data == 2:
			if var_list[1] == "addr-port":
				print "\tget addr-port data"
				collect_ss7boost_data = collect_ss7boost_data + 1
			else:
				print "FATAL: ss7boost section, missing addr-port header line"
				print var_list
				sys.exit(3)
		elif collect_ss7boost_data == 3:
			if var_list[1] == "ss7box":
				print "\tget ss7box addr-port data"
				ss7boost_ss7box_ap = var_list
				collect_ss7boost_data = collect_ss7boost_data + 1
			else:
				print "\t\tFATAL: ss7boost section, addr-port, missing ss7box section"
				print var_list
				sys.exit(3)
		elif collect_ss7boost_data == 4:
			if var_list[1] == "t/g":
				print "\tget trunk group data"
			elif var_list[1].strip() == "end":
				collect_ss7boost_data = collect_ss7boost_data + 1
			elif var_list[1] == str(tg_cnt):
				print "\t\ttrunk group: %s" % var_list[1]
				trunk_group.append(var_list)
				#print isup_rte
				tg_cnt = tg_cnt + 1
			elif var_list[1] == "":
				print "\t\tempty line in trunk group section"
			else:
				print "FATAL: poorly formed trunk group section"
				print var_list
				sys.exit(3)
		else:
			print "extra stuff at the end of the ss7boost section"
			print var_list
	#print var_list
	#sys.stderr.write(L)
	if var_list[0] == "protocol":
		protocol = var_list[1].strip()
		print "protocol: %s" % protocol
	if var_list[0] == "ports":
		if protocol == "":
			print "protocol not defined"
			sys.exit(3)
		print "PORTS BEGIN"
		found_ports_section = 1
	if var_list[0] == "ss7box":
		print "SS7BOX BEGIN"
                ss7box_on_this_node = var_list[2].strip()
		if ss7box_on_this_node.lower() == "yes":
			print "\tss7box running on this node"
			collect_ss7box_data = 1
		else:
			print "\tss7box not running on this node"
		found_ss7box_section = 1
	if var_list[0] == "ss7boost":
		print "SS7BOOST BEGIN"
		found_ss7boost_section = 1
		collect_ss7boost_data = 1
		if var_list[1] == "SPC":
			ss7boost_spc = var_list[2].strip()
		else:
			print "poorly formed ss7boost SPC section"
			sys.exit(3)
	L = fin.readline ()

# write conf files

for port_entry in port:
	if port_entry[10] != "":
		#print "\twanpipe %s has an ss7 link" % port_entry[1]
		if first_wanpipe_with_ss7_link_found:
			make_wanpipe_conf_file (0, port_entry)
		else:
			make_wanpipe_conf_file (1, port_entry)
			first_wanpipe_with_ss7_link_found = 1
	else:
		make_wanpipe_conf_file (0, port_entry)

if collect_ss7box_data:
	write_ss7box_conf (port, protocol, ss7box_spc, ac, lslink, ls, path, rte, isup_rte)
		
write_ss7boost_conf (
	protocol, 
	ss7boost_spc, 
	ss7boost_sysid,
	ss7boost_ss7box_ap,
	port,
	trunk_group)

print "FINISHED"
